# GithubMaker
![Version 1.1.0](https://img.shields.io/badge/version-1.1.0-blue) ![License](https://img.shields.io/badge/Licence-MIT-green) ![Maintenance](https://img.shields.io/maintenance/yes/2023)

Creates Github related documents easily.

## Features
* Creates Code of Conduct
* Creates Contributing Guide
* Creates License
* Creates Readme template
* Creates Security
* Creates Github template files
* Creates Gitignore file according to the OS type and programming languages that you use

## Dependencies
* Python is required for this project to work.

## Setup
* [WILL BE CHANGED IN NEXT UPDATES]

## Usage
[WILL BE CHANGED IN NEXT UPDATES]
